@@ -1,10 +1,11 @@
-from .chibi_csv import Chibi_csv
 import os
+from .chibi_csv import Chibi_csv
 from .chibi_yaml import Chibi_yaml
 from .chibi_json import Chibi_json
+from .chibi_python import Chibi_python
 
 
-__all__ = [ 'Chibi_csv', 'Chibi_yaml', 'Chibi_json' ]
+__all__ = [ 'Chibi_csv', 'Chibi_yaml', 'Chibi_json', 'Chibi_python' ]
 
 
 def find_correct_class( path, cls ):
@@ -15,4 +16,6 @@ def find_correct_class( path, cls ):
         return Chibi_yaml
     elif ext == '.json':
         return Chibi_json
+    elif ext == '.py':
+        return Chibi_python
     return cls
